# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
from django.db.utils import IntegrityError
from apella.util import normalize_index_field


def migrate_disciplines(apps, schema_editor):
    Discipline = apps.get_model("apella", "Discipline")
    DisciplineRegistry = apps.get_model("apella", "DisciplineRegistry")

    registries = DisciplineRegistry.objects.all()
    for registry in registries:
        for discipline in registry.disciplines.all():
            try:
                discipline.department = registry.department
                discipline.discipline_text_el_index = \
                        normalize_index_field(discipline.scientific_field.el) + \
                        "::" + \
                        normalize_index_field(discipline.discipline_text.el)
                discipline.save()
            except IntegrityError:
                print(
                    "UNIQUE constraint failed: department: %s, discipline_text_el_index: %s" %
                    (registry.department.id, discipline.discipline_text.el))
                continue


class Migration(migrations.Migration):

    dependencies = [
        ('apella', '0087_auto_20230418_1341'),
    ]

    operations = [
        migrations.RunPython(migrate_disciplines),
    ]
